Index: src/ports/SkMemory_malloc.cpp |
diff --git a/src/ports/SkMemory_malloc.cpp b/src/ports/SkMemory_malloc.cpp |
index f9836c0e0e03764a8d82673536993ff52b42943c..6ad01daca0fe0b58115ae0f0c76e9131862bc87b 100644 |
--- a/src/ports/SkMemory_malloc.cpp |
+++ b/src/ports/SkMemory_malloc.cpp |
@@ -19,8 +19,8 @@ static inline void sk_out_of_memory(size_t size) { |
} |
static inline void* throw_on_failure(size_t size, void* p) { |
- if (size > 0 && p == NULL) { |
- // If we've got a NULL here, the only reason we should have failed is running out of RAM. |
+ if (size > 0 && p == nullptr) { |
+ // If we've got a nullptr here, the only reason we should have failed is running out of RAM. |
sk_out_of_memory(size); |
} |
return p; |